@@ -3,16 +3,16 @@ import re
 
 class SideStep:
 
-    def __init__(self, step, pipeline_id, globals):
+    def __init__(self, step, pipeline_id, g):
         self.step = step
         self.pipeline_id = pipeline_id
-        self.globals = globals
+        self.g = g
 
         if self.pipeline_id:
-            exec(self.step, self.globals)
+            exec(self.step, self.g)
         else:
             self.side_step = self.dlt_removal()
-            exec(self.side_step, self.globals)
+            exec(self.side_step, self.g)
             print(self.side_step)
 
     def dlt_removal(self):
